@@ -1,5 +1,5 @@
 #
-# $Id: Tool.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Tool.pm,v 811ac7ccde81 2016/02/22 18:15:08 gomor $
 #
 # brik::tool Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: 811ac7ccde81 $',
       tags => [ qw(unstable program) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -24,7 +24,10 @@ sub brik_properties {
       },
       commands => {
          get_require_modules => [ qw(Brik|OPTIONAL) ],
+         get_require_modules_recursive => [ qw(Brik) ],
          get_need_packages => [ qw(Brik|OPTIONAL) ],
+         get_need_packages_recursive => [ qw(Brik) ],
+         get_brik_hierarchy => [ qw(Brik) ],
          install_all_require_modules => [ ],
          install_all_need_packages => [ ],
          install_needed_packages => [ qw(Brik) ],
@@ -34,6 +37,7 @@ sub brik_properties {
          update_core => [ ],
          update_repository => [ ],
          test_repository => [ ],
+         view_brik_source => [ qw(Brik) ],
       },
       require_modules => {
          'Metabrik::Devel::Mercurial' => [ ],
@@ -83,6 +87,51 @@ sub get_require_modules {
    return [ sort { $a cmp $b } keys %modules ];
 }
 
+sub get_require_modules_recursive {
+   my $self = shift;
+   my ($brik) = @_;
+
+   # We force to use only one Brik, cause recursion on all Briks takes a too long time.
+   $self->brik_help_run_undef_arg('get_require_modules_recursive', $brik) or return;
+
+   my $con = $self->context;
+   my $available = $con->available;
+
+   my $list = $self->get_brik_hierarchy($brik) or return;
+   my $new = { $brik => $available->{$brik} };  # Don't forget myself
+   for my $this (@$list) {
+      $new->{$this} = $available->{$this};
+   }
+   $available = $new;
+
+   my %modules = ();
+   for my $this (keys %$available) {
+      next if $this =~ m{^core::};
+      #print "available [$this]\n";
+      if (exists($available->{$this}->brik_properties->{require_modules})) {
+         my $list = $available->{$this}->brik_properties->{require_modules};
+         for my $m (keys %$list) {
+            if ($m =~ m{^Metabrik::}) {
+               (my $name = $m) =~ s/^Metabrik:://;
+               $name = lc($name);
+               #print "BRIK [$name]\n";
+               my $new = $self->get_require_modules($name);
+               for (@$new) {
+                  #print "new [$_] for [$name]\n";
+                  $modules{$_}++;
+               }
+            }
+            else {
+               #print "module [$m]\n";
+               $modules{$m}++;
+            }
+         }
+      }
+   }
+
+   return [ sort { $a cmp $b } keys %modules ];
+}
+
 sub get_need_packages {
    my $self = shift;
    my ($brik) = @_;
@@ -113,6 +162,74 @@ sub get_need_packages {
    return [ sort { $a cmp $b } keys %packages ];
 }
 
+sub get_need_packages_recursive {
+   my $self = shift;
+   my ($brik) = @_;
+
+   # We force to use only one Brik, cause recursion on all Briks takes a too long time.
+   $self->brik_help_run_undef_arg('get_need_packages_recursive', $brik) or return;
+
+   my $con = $self->context;
+   my $available = $con->available;
+
+   my $list = $self->get_brik_hierarchy($brik) or return;
+   my $new = { $brik => $available->{$brik} };  # Don't forget myself
+   for my $this (@$list) {
+      $new->{$this} = $available->{$this};
+   }
+   $available = $new;
+
+   my $sp = Metabrik::System::Package->new_from_brik_init($self) or return;
+   my $os = $sp->my_os or return;
+
+   my %packages = ();
+   for my $this (keys %$available) {
+      next if $this =~ m{^core::};
+      if (exists($available->{$this}->brik_properties->{need_packages})) {
+         my $list = $available->{$this}->brik_properties->{need_packages}{$os} or next;
+         for my $p (@$list) {
+            $packages{$p}++;
+         }
+      }
+   }
+
+   return [ sort { $a cmp $b } keys %packages ];
+}
+
+sub get_brik_hierarchy {
+   my $self = shift;
+   my ($brik) = @_;
+
+   $self->brik_help_run_undef_arg('get_brik_hierarchy', $brik) or return;
+
+   my @toks = split(/::/, $brik);
+   if (@toks < 2) {
+      return $self->log->error("get_brik_hierarchy: invalid Brik format for [$brik]");
+   }
+
+   my @final = ();
+
+   my $m = 'Metabrik';
+   for (@toks) {
+      $_ = ucfirst($_);
+      $m .= "::$_";
+   }
+   {
+      no strict 'refs';
+      my @isa = @{$m.'::ISA'};
+      for (@isa) {
+         next unless /^Metabrik::/;
+         (my $name = $_) =~ s/^Metabrik:://;
+         $name = lc($name);
+         push @final, $name;
+         my $list = $self->get_brik_hierarchy($name) or next;
+         push @final, @$list;
+      }
+   }
+
+   return \@final;
+}
+
 sub install_all_need_packages {
    my $self = shift;
 
@@ -158,77 +275,63 @@ sub install_needed_packages {
    my $self = shift;
    my ($brik) = @_;
 
-   my $con = $self->context;
+   $self->brik_help_run_undef_arg('install_needed_packages', $brik) or return;
 
-   my $avail = $con->find_available;
-   if (! exists($avail->{$brik})) {
-      return $self->log->error("install_needed_packages: Brik [$brik] not available");
+   my $packages = $self->get_need_packages_recursive($brik) or return;
+   if (@$packages == 0) {
+      return 1;
    }
 
-   my $module = $avail->{$brik};
-
-   my $b = $module->new_from_brik_no_checks($self) or return;
-   if (exists($b->brik_properties->{commands}{install})) {
-      return $b->install;
-   }
-
-   return 1;
+   my $sp = Metabrik::System::Package->new_from_brik_init($self) or return;
+   return $sp->install($packages);
 }
 
 sub install_required_modules {
    my $self = shift;
    my ($brik) = @_;
 
-   my $con = $self->context;
+   $self->brik_help_run_undef_arg('install_required_modules', $brik) or return;
 
-   my $avail = $con->find_available;
-   if (! exists($avail->{$brik})) {
-      return $self->log->error("install_required_modules: Brik [$brik] not available");
+   my $modules = $self->get_require_modules_recursive($brik) or return;
+   if (@$modules == 0) {
+      return 1;
    }
 
-   my $module = $avail->{$brik};
-
    my $pm = Metabrik::Perl::Module->new_from_brik_init($self) or return;
-
-   my $m = $module->new_from_brik_no_checks($self) or return;
-   if (exists($m->brik_properties->{require_modules})) {
-      return $pm->install([ sort { $a cmp $b } keys %{$m->brik_properties->{require_modules}} ]);
-   }
-
-   return 1;
+   return $pm->install($modules);
 }
 
 sub create_tool {
    my $self = shift;
    my ($filename, $repository) = @_;
 
-   $repository ||= $self->repository;
+   $repository ||= $self->repository || '';
    $self->brik_help_run_undef_arg('create_tool', $filename) or return;
-   $self->brik_help_run_undef_arg('create_tool', $repository) or return;
 
    my $ft = Metabrik::File::Text->new_from_brik_init($self) or return;
 
    my $data =<<EOF
-#!/usr/bin/perl
+#!/usr/bin/env perl
 #
 # \$Id\$
 #
 use strict;
 use warnings;
 
-use lib qw($repository/lib);
+# Uncomment to use a custom repository
+#use lib qw($repository/lib);
 
 use Data::Dumper;
 use Metabrik::Core::Context;
-
-# Put your Briks here
+# Put other Briks to use here
+# use Metabrik::File::Text;
 
 my \$con = Metabrik::Core::Context->new or die("core::context");
 
-# Init your Briks here
+# Init other Briks here
 # my \$ft = Metabrik::File::Text->new_from_brik_init(\$con) or die("file::text");
 
-# Put your Tool code here
+# Put Metatool code here
 # \$ft->write("test", "/tmp/test.txt");
 
 exit(0);
@@ -284,7 +387,7 @@ package $package;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
@@ -298,6 +401,7 @@ sub brik_properties {
       attributes_default => {
       },
       commands => {
+         install => [ ],  # Inherited
       },
       require_modules => {
       },
@@ -393,7 +497,7 @@ sub update_core {
 
    my $datadir = $self->datadir;
 
-   my $url = 'http://trac.metabrik.org/hg/core';
+   my $url = 'https://www.metabrik.org/hg/core';
 
    my $dm = Metabrik::Devel::Mercurial->new_from_brik_init($self) or return;
    $dm->use_pager(0);
@@ -424,7 +528,7 @@ sub update_repository {
    my $datadir = $self->datadir;
    my $repository = $self->global->repository || $datadir.'/repository';
 
-   my $url = 'http://trac.metabrik.org/hg/repository';
+   my $url = 'https://www.metabrik.org/hg/repository';
 
    my $dm = Metabrik::Devel::Mercurial->new_from_brik_init($self) or return;
    $dm->use_pager(0);
@@ -473,6 +577,41 @@ sub test_repository {
    return 1;
 }
 
+sub view_brik_source {
+   my $self = shift;
+   my ($brik) = @_;
+
+   $self->brik_help_run_undef_arg('view_brik_source', $brik) or return;
+
+   my @toks = split(/::/, $brik);
+   if (@toks < 2) {
+      return $self->log->error("view_brik_source: invalid Brik format for [$brik]");
+   }
+
+   my $pager = $ENV{PAGER} || 'less';
+
+   my $pm = 'Metabrik';
+   for (@toks) {
+      $_ = ucfirst($_);
+      $pm .= "/$_";
+   }
+   $pm .= '.pm';
+
+   my $cmd = '';
+   for (@INC) {
+      if (-f "$_/$pm") {
+         $cmd = "$pager $_/$pm";
+         last;
+      }
+   }
+
+   if (length($cmd) == 0) {
+      return $self->log->error("view_brik_source: unable to find Brik [$brik] in \@INC");
+   }
+
+   return $self->system($cmd);
+}
+
 1;
 
 __END__
