@@ -1,5 +1,5 @@
 #
-# $Id: Whois.pm,v 550398ff8391 2015/11/18 06:15:52 gomor $
+# $Id: Whois.pm,v 515763761308 2016/02/08 20:39:05 gomor $
 #
 # client::whois Brik
 #
@@ -11,14 +11,17 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 550398ff8391 $',
-      tags => [ qw(unstable client whois) ],
+      revision => '$Revision: 515763761308 $',
+      tags => [ qw(unstable) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
-         ip => [ qw(ip_address) ],
-         domain => [ qw(domain) ],
+         from_ip => [ qw(ip_address) ],
+         from_domain => [ qw(domain) ],
          is_available_domain => [ qw(domain) ],
          parse_raw_whois => [ qw($lines_list) ],
          normalize_raw_ip_whois => [ qw($chunks $lines_list) ],
+         is_ip_from_owner => [ qw(ip_address owner) ],
       },
       require_modules => {
          'Metabrik::Network::Address' => [ ],
@@ -32,9 +35,7 @@ sub parse_raw_whois {
    my $self = shift;
    my ($lines) = @_;
 
-   if (! defined($lines)) {
-      return $self->log->error($self->brik_help_run('parse_raw_whois'));
-   }
+   $self->brik_help_run_undef_arg('parse_raw_whois', $lines) or return;
 
    my $sp = Metabrik::String::Parse->new_from_brik_init($self) or return;
    my $chunks = $sp->split_by_blank_line($lines) or return;
@@ -131,9 +132,8 @@ sub normalize_raw_ip_whois {
    my $self = shift;
    my ($chunks, $lines) = @_;
 
-   if (! defined($chunks) || ! defined($lines)) {
-      return $self->log->error($self->brik_help_run('normalize_raw_ip_whois'));
-   }
+   $self->brik_help_run_undef_arg('normalize_raw_ip_whois', $chunks) or return;
+   $self->brik_help_run_undef_arg('normalize_raw_ip_whois', $lines) or return;
 
    my $r = { raw => $lines };
    #my $r = {};
@@ -146,19 +146,22 @@ sub normalize_raw_ip_whois {
    # We search for the first chunk with an inetnum.
    my $general;
    for (@$chunks) {
-      if (exists($_->{inetnum}) || exists($_->{netrange}) || exists($_->{network})) {
+      if (exists($_->{inetnum}) || exists($_->{netrange}) || exists($_->{network}) || exists($_->{ip_network})) {
          $general = $_;
          last;
       }
    }
    if (! defined($general)) {
+      use Data::Dumper;
+      print Dumper($chunks)."\n";
       return $self->log->error("normalize_raw_ip_whois: no inetnum found in this record");
    }
 
-   # inetnum,netrange,network,
+   # inetnum,netrange,network,ip_network
    $self->_ip_lookup($general, 'inetnum', 'inetnum', $r);
    $self->_ip_lookup($general, 'netrange', 'inetnum', $r);
    $self->_ip_lookup($general, 'network', 'inetnum', $r);
+   $self->_ip_lookup($general, 'ip_network', 'inetnum', $r);
    # cidr,
    $self->_ip_lookup($general, 'cidr', 'cidr', $r);
    # nethandle,
@@ -270,13 +273,11 @@ sub normalize_raw_ip_whois {
    return $r;
 }
 
-sub ip {
+sub from_ip {
    my $self = shift;
    my ($ip) = @_;
 
-   if (! defined($ip)) {
-      return $self->log->error($self->brik_help_run('ip'));
-   }
+   $self->brik_help_run_undef_arg('ip', $ip) or return;
 
    my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
    if (! $na->is_ip($ip)) {
@@ -309,13 +310,11 @@ sub _domain_lookup {
    return $this;
 }
 
-sub domain {
+sub from_domain {
    my $self = shift;
    my ($domain) = @_;
 
-   if (! defined($domain)) {
-      return $self->log->error($self->brik_help_run('domain'));
-   }
+   $self->brik_help_run_undef_arg('domain', $domain) or return;
 
    my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
    if ($na->is_ip($domain)) {
@@ -426,15 +425,29 @@ sub is_available_domain {
    my $self = shift;
    my ($domain) = shift;
 
-   if (! defined($domain)) {
-      return $self->log->brik_help_run('is_available');
-   }
+   $self->brik_help_run_undef_arg('is_available_domain', $domain) or return;
 
    my $info = $self->domain($domain) or return;
 
    return $info->{domain_exists};
 }
 
+sub is_ip_from_owner {
+   my $self = shift;
+   my ($ip, $owner) = @_;
+
+   $self->brik_help_run_undef_arg('is_ip_from_owner', $ip) or return;
+   $self->brik_help_run_undef_arg('is_ip_from_owner', $owner) or return;
+
+   my $r = $self->ip($ip) or return;
+   if ((exists($r->{description}) && $r->{description} =~ m{$owner}i)
+   ||  (exists($r->{organization}) && $r->{organization} =~ m{$owner}i)) {
+      return 1;
+   }
+
+   return 0;
+}
+
 1;
 
 __END__
@@ -445,7 +458,7 @@ Metabrik::Client::Whois - client::whois Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
