@@ -1,5 +1,5 @@
 #
-# $Id: Www.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Www.pm,v b0ac8f9260b0 2016/02/18 17:50:27 gomor $
 #
 # client::www Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: b0ac8f9260b0 $',
       tags => [ qw(unstable browser http javascript screenshot) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -55,7 +55,7 @@ sub brik_properties {
          screenshot => [ qw(uri output) ],
          eval_javascript => [ qw(js uri) ],
          info => [ qw(uri|OPTIONAL) ],
-         mirror => [ qw(url|$url_list output datadir|OPTIONAL) ],
+         mirror => [ qw(url|$url_list output|OPTIONAL datadir|OPTIONAL) ],
          parse => [ qw(html) ],
       },
       require_modules => {
@@ -70,15 +70,16 @@ sub brik_properties {
          'WWW::Mechanize' => [ ],
          'Metabrik::File::Write' => [ ],
          'Metabrik::Client::Ssl' => [ ],
+         'Metabrik::System::File' => [ ],
       },
       optional_modules => {
          'WWW::Mechanize::PhantomJS' => [ ],
       },
       optional_binaries => {
-         'phantomjs' => [ ],
+         phantomjs => [ ],
       },
       need_packages => {
-         'ubuntu' => [ qw(libssl-dev phantomjs) ],
+         ubuntu => [ qw(libssl-dev phantomjs) ],
       },
    };
 }
@@ -562,10 +563,12 @@ sub mirror {
 
    $datadir ||= $self->datadir;
    $self->brik_help_run_undef_arg('mirror', $url) or return;
-   $self->brik_help_run_undef_arg('mirror', $output) or return;
+   my $ref = $self->brik_help_run_invalid_arg('mirror', $url, 'SCALAR', 'ARRAY') or return;
 
    my @files = ();
-   if (ref($url) eq 'ARRAY') {
+   if ($ref eq 'ARRAY') {
+      $self->brik_help_run_empty_array_arg('mirror', $url) or return;
+
       for my $this (@$url) {
          my $file = $self->mirror($this, $output) or next;
          push @files, @$file;
@@ -576,6 +579,17 @@ sub mirror {
          return $self->log->error("mirror: invalid URL [$url]");
       }
 
+      my $sf = Metabrik::System::File->new_from_brik_init($self) or return;
+      if (! defined($output)) {
+         my $filename = $sf->basefile($url) or return;
+         $output = $datadir.'/'.$filename;
+      }
+      else { # $output is defined
+         if (! $sf->is_absolute($output)) {  # We want default datadir for output file
+            $output = $datadir.'/'.$output;
+         }
+      }
+
       $self->debug && $self->log->debug("mirror: url[$url] output[$output]");
 
       my $mech = $self->create_user_agent or return;
@@ -584,7 +598,7 @@ sub mirror {
 
       my $rc;
       eval {
-         $rc = $mech->mirror($url, $datadir.'/'.$output);
+         $rc = $mech->mirror($url, $output);
       };
       if ($@) {
          chomp($@);
@@ -592,9 +606,8 @@ sub mirror {
       }
       my $code = $rc->code;
       if ($code == 200) {
-         my $file = $datadir.'/'.$output;
-         push @files, $file;
-         $self->log->info("mirror: downloading URL [$url] to local file [$file] done");
+         push @files, $output;
+         $self->log->info("mirror: downloading URL [$url] to local file [$output] done");
       }
       elsif ($code == 304) { # Not modified
          $self->log->info("mirror: file [$output] not modified since last check");
