@@ -1,5 +1,5 @@
 #
-# $Id: Csv.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Csv.pm,v 7a8b06b06dbc 2016/02/26 05:56:21 gomor $
 #
 # file::csv Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: 7a8b06b06dbc $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -23,18 +23,26 @@ sub brik_properties {
          header => [ qw($column_header_list) ],
          encoding => [ qw(utf8|ascii) ],
          overwrite => [ qw(0|1) ],
+         append => [ qw(0|1) ],
+         write_header => [ qw(0|1) ],
+         _csv => [ qw(INTERNAL) ],
+         _fd => [ qw(INTERNAL) ],
+         _header_written => [ qw(INTERNAL) ],
       },
       attributes_default => {
          first_line_is_header => 1,
-         header => [ ],
          separator => ';',
          encoding => 'utf8',
          overwrite => 1,
+         append => 0,
+         write_header => 1,
+         _header_written => 0,
       },
       commands => {
          read => [ qw(input_file|OPTIONAL) ],
          write => [ qw(csv_struct output_file|OPTIONAL) ],
          get_column_values => [ qw($data column_name|column_int) ],
+         read_next => [ qw(input_file|OPTIONAL) ],
       },
       require_modules => {
          'Text::CSV_XS' => [ ],
@@ -49,7 +57,8 @@ sub read {
    my ($input) = @_;
 
    $input ||= $self->input;
-   $self->brik_help_run_undef_arg("read", $input) or return;
+   $self->brik_help_run_undef_arg('read', $input) or return;
+   $self->brik_help_run_file_not_found('read', $input) or return;
 
    my $csv = Text::CSV_XS->new({
       binary => 1,
@@ -99,22 +108,18 @@ sub read {
    return \@rows;
 }
 
+#
+# We only handle ARRAY of HASHes format (aoh) for writing
+#
 sub write {
    my $self = shift;
    my ($csv_struct, $output) = @_;
 
    $output ||= $self->output;
-   $self->brik_help_run_undef_arg("write", $csv_struct) or return;
-   $self->brik_help_run_undef_arg("write", $output) or return;
-
-   # We handle handle array of hashes format (aoh) for writing
-   if (ref($csv_struct) ne 'ARRAY') {
-      return $self->log->error("write: csv structure is not ARRAY");
-   }
-
-   if (! scalar(@$csv_struct)) {
-      return $self->log->error("write: csv structure is empty, nothing to write");
-   }
+   $self->brik_help_run_undef_arg('write', $csv_struct) or return;
+   $self->brik_help_run_invalid_arg('write', $csv_struct, 'ARRAY') or return;
+   $self->brik_help_run_empty_array_arg('write', $csv_struct, 'ARRAY') or return;
+   $self->brik_help_run_undef_arg('write', $output) or return;
 
    if (ref($csv_struct->[0]) ne 'HASH') {
       return $self->log->error("write: csv structure does not contain HASHes");
@@ -125,31 +130,56 @@ sub write {
    my $fw = Metabrik::File::Write->new_from_brik_init($self) or return;
    $fw->output($output);
    $fw->encoding($self->encoding);
+   $fw->overwrite($self->overwrite);
+   $fw->append($self->append);
    my $fd = $fw->open or return;
 
    my $written = '';
 
-   my $header_written = 0;
+   # If header is provided, we use it to respect the order.
+   my $header_set = 0;
    my %order = ();
-   for my $this (@$csv_struct) {
-      if (! $header_written) {
-         my $idx = 0;
-         for my $k (sort { $a cmp $b } keys %$this) {
-            $order{$k} = $idx;
-            $idx++;
-         }
-         my @header = sort { $a cmp $b } keys %$this;
+   if ($self->header) {
+      my @header = @{$self->header};
+      my $idx = 0;
+      for my $k (@header) {
+         $order{$k} = $idx;
+         $idx++;
+      }
+      if ($self->write_header && ! $self->_header_written) {
          my $data = join($self->separator, @header)."\n";
          print $fd $data;
          $written .= $data;
-         $header_written++;
+         $self->_header_written(1);
+      }
+      $header_set++;
+   }
+
+   for my $this (@$csv_struct) {
+      # If header was not provided, we use our own ordering
+      if (! $header_set) {
+         my @header = sort { $a cmp $b } keys %$this;
+         my $idx = 0;
+         for my $k (@header) {
+            $order{$k} = $idx;
+            $idx++;
+         }
+         if ($self->write_header && ! $self->_header_written) {
+            my $data = join($self->separator, @header)."\n";
+            print $fd $data;
+            $written .= $data;
+            $self->_header_written(1);
+         }
+         $header_set++;
       }
 
       my @fields = ();
-      for my $key (sort { $a cmp $b } keys %$this) {
+      for my $key (keys %$this) {
+         next if (! defined($order{$key}));  # We may have some unwanted data in this HASH
          $fields[$order{$key}] = $this->{$key};
       }
 
+      @fields = map { defined($_) ? $_ : 'undef' } @fields;
       my $data = join($self->separator, @fields)."\n";
 
       my $r = $fw->write($data);
@@ -173,9 +203,9 @@ sub get_column_values {
    my $self = shift;
    my ($data, $column) = @_;
 
-   $self->brik_help_run_undef_arg("get_column_values", $data) or return;
-   $self->brik_help_run_undef_arg("get_column_values", $column) or return;
-   $self->brik_help_run_invalid_arg("get_column_values", $data, 'ARRAY') or return;
+   $self->brik_help_run_undef_arg('get_column_values', $data) or return;
+   $self->brik_help_run_invalid_arg('get_column_values', $data, 'ARRAY') or return;
+   $self->brik_help_run_undef_arg('get_column_values', $column) or return;
 
    my @results = ();
    # CSV structure is an ARRAYREF of HASHREFs
@@ -210,6 +240,60 @@ sub get_column_values {
    return \@results;
 }
 
+sub read_next {
+   my $self = shift;
+   my ($input) = @_;
+
+   $input ||= $self->input;
+   $self->brik_help_run_undef_arg('read_next', $input) or return;
+   $self->brik_help_run_file_not_found('read_next', $input) or return;
+
+   my $csv = $self->_csv;
+   my $fd = $self->_fd;
+   if (! defined($csv)) {
+      $self->debug && $self->log->debug('read_next: first call, create _csv');
+      $csv = Text::CSV_XS->new({
+         binary => 1,
+         sep_char => $self->separator,
+         allow_loose_quotes => 1,
+         allow_loose_escapes => 1,
+      }) or return $self->log->error('read_next: Text::CSV_XS new failed');
+      $self->_csv($csv);
+
+      my $fr = Metabrik::File::Read->new_from_brik_init($self) or return;
+      $fr->encoding($self->encoding);
+      $fd = $fr->open($input) or return;
+      $self->_fd($fd);
+
+      if ($self->first_line_is_header) {
+         my $header = $csv->getline($fd);
+         $self->header($header);
+      }
+   }
+
+   my $row = $csv->getline($fd);
+
+   # If a header is given as an Attribute, we use it to return a HASH
+   my $header = $self->header;
+   if (defined($header)) {
+      my $h = {};
+      my $i = 0;
+      for (@$header) {
+         $h->{$_} = $row->[$i++];
+      }
+      $row = $h;
+   }
+
+   if ($csv->eof) {
+      $self->debug && $self->log->debug('read_next: eof reached');
+      $self->_fd(undef);
+      $self->_csv(undef);
+      return 0;
+   }
+
+   return $row;
+}
+
 1;
 
 __END__
