@@ -1,5 +1,5 @@
 #
-# $Id: Dual.pm,v 259de0608971 2015/11/10 17:51:32 gomor $
+# $Id: Dual.pm,v 3a618b2c89fc 2016/02/01 06:36:57 gomor $
 #
 # log::dual Brik
 #
@@ -7,15 +7,17 @@ package Metabrik::Log::Dual;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::Core::Log);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 259de0608971 $',
-      tags => [ qw(log) ],
+      revision => '$Revision: 3a618b2c89fc $',
+      tags => [ qw(unstable logging) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          level => [ qw(0|1|2|3) ],
-         output_file => [ qw(file) ],
+         output => [ qw(file) ],
          time_prefix => [ qw(0|1) ],
          text_prefix => [ qw(0|1) ],
          _fd => [ qw(file_descriptor) ],
@@ -23,6 +25,7 @@ sub brik_properties {
       attributes_default => {
          time_prefix => 0,
          text_prefix => 0,
+         output => '/tmp/dual.log',
       },
       commands => {
          info => [ qw(string caller|OPTIONAL) ],
@@ -45,35 +48,16 @@ sub brik_use_properties {
       attributes_default => {
          debug => $self->log->debug,
          level => $self->log->level,
-         output_file => $self->global->output,
       },
    };
 }
 
-sub brik_preinit {
-   my $self = shift;
-
-   my $context = $self->context;
-
-   # We replace the current logging Brik by this one.
-   $context->{log} = $self;
-   for my $this (keys %{$context->used}) {
-      $context->{used}->{$this}->{log} = $self;
-   }
-
-   # We have to init this new log Brik, because previous one
-   # was already inited at this stage. We have to keep the same init context.
-   $self->brik_init or return $self->log->error("brik_preinit: init error");
-
-   return $self;
-}
-
 sub brik_init {
    my $self = shift;
 
-   my $output_file = $self->output_file;
-   open(my $fd, '>', $output_file)
-      or return $self->log->error("brik_init: can't open output file [$output_file]: $!");
+   my $output = $self->output;
+   open(my $fd, '>', $output)
+      or return $self->log->error("brik_init: can't open output file [$output]: $!");
 
    # Makes the file handle unbuffered
    my $current = select;
@@ -101,8 +85,8 @@ sub warning {
    my $self = shift;
    my ($msg, $caller) = @_;
 
-   my $prefix = $self->text_prefix ? "WARN " : "[!]";
-   my $time = $self->time_prefix ? localtime()." " : " ";
+   my $prefix = $self->text_prefix ? 'WARN ' : '[!]';
+   my $time = $self->time_prefix ? localtime().' ' : '';
    my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
 
    my $fd = $self->_fd;
@@ -117,8 +101,8 @@ sub error {
    my $self = shift;
    my ($msg, $caller) = @_;
 
-   my $prefix = $self->text_prefix ? "ERROR" : "[-]";
-   my $time = $self->time_prefix ? localtime()." " : " ";
+   my $prefix = $self->text_prefix ? 'ERROR' : '[-]';
+   my $time = $self->time_prefix ? localtime().' ' : '';
    my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
 
    my $fd = $self->_fd;
@@ -135,8 +119,8 @@ sub fatal {
    my $self = shift;
    my ($msg, $caller) = @_;
 
-   my $prefix = $self->text_prefix ? "FATAL" : "[F]";
-   my $time = $self->time_prefix ? localtime()." " : " ";
+   my $prefix = $self->text_prefix ? 'FATAL' : '[F]';
+   my $time = $self->time_prefix ? localtime().' ' : '';
    my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
 
    my $fd = $self->_fd;
@@ -153,8 +137,8 @@ sub info {
 
    $msg ||= 'undef';
 
-   my $prefix = $self->text_prefix ? "INFO " : "[+]";
-   my $time = $self->time_prefix ? localtime()." " : " ";
+   my $prefix = $self->text_prefix ? 'INFO ' : '[+]';
+   my $time = $self->time_prefix ? localtime().' ' : '';
    my $buffer = $time."$prefix $msg\n";
 
    my $fd = $self->_fd;
@@ -171,8 +155,8 @@ sub verbose {
 
    return 1 unless $self->level > 1;
 
-   my $prefix = $self->text_prefix ? "VERB " : "[*]";
-   my $time = $self->time_prefix ? localtime()." " : " ";
+   my $prefix = $self->text_prefix ? 'VERB ' : '[*]';
+   my $time = $self->time_prefix ? localtime().' ' : '';
    my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
 
    my $fd = $self->_fd;
@@ -202,8 +186,8 @@ sub debug {
       else {
          return 1 unless $self->level > 2;
 
-         my $prefix = $self->text_prefix ? "DEBUG" : "[D]";
-         my $time = $self->time_prefix ? localtime()." " : " ";
+         my $prefix = $self->text_prefix ? 'DEBUG' : '[D]';
+         my $time = $self->time_prefix ? localtime().' ' : '';
          my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
 
          my $fd = $self->_fd;
@@ -238,7 +222,7 @@ Metabrik::Log::Dual - log::dual Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
