@@ -1,5 +1,5 @@
 #
-# $Id: Null.pm,v 02964d3ea8ac 2015/11/10 08:41:24 gomor $
+# $Id: Null.pm,v 3a618b2c89fc 2016/02/01 06:36:57 gomor $
 #
 # log::null Brik
 #
@@ -7,12 +7,14 @@ package Metabrik::Log::Null;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::Core::Log);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 02964d3ea8ac $',
-      tags => [ qw(log null) ],
+      revision => '$Revision: 3a618b2c89fc $',
+      tags => [ qw(unstable logging) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          level => [ qw(0|1|2|3) ],
       },
@@ -27,24 +29,6 @@ sub brik_properties {
    };
 }
 
-sub brik_preinit {
-   my $self = shift;
-
-   my $context = $self->context;
-
-   # We replace the current logging Brik by this one.
-   $context->{log} = $self;
-   for my $this (keys %{$context->used}) {
-      $context->{used}->{$this}->{log} = $self;
-   }
-
-   # We have to init this new log Brik, because previous one
-   # was already inited at this stage. We have to keep the same init context.
-   $self->brik_init or return $self->log->error("brik_preinit: init error");
-
-   return $self;
-}
-
 sub _msg {
    my $self = shift;
    my ($brik, $msg) = @_;
@@ -105,7 +89,7 @@ Metabrik::Log::Null - log::null Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
