@@ -1,5 +1,5 @@
 #
-# $Id: Countrycode.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Countrycode.pm,v 35a2fef2b5f8 2016/01/19 13:11:10 gomor $
 #
 # lookup::countrycode Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
-      tags => [ qw(unstable lookup iana countrycode cc) ],
+      revision => '$Revision: 35a2fef2b5f8 $',
+      tags => [ qw(unstable iana cc) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
          input => [ qw(file) ],
@@ -24,7 +26,6 @@ sub brik_properties {
       },
       commands => {
          update => [ ],
-         save => [ qw($csv_struct output|OPTIONAL) ],
          load => [ qw(input|OPTIONAL) ],
          country_code_types => [ qw($csv_struct) ],
       },
@@ -38,9 +39,7 @@ sub country_code_types {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('country_code_types'));
-   }
+   $self->brik_help_run_undef_arg('country_code_types', $data) or return;
 
    my %list = ();
    for my $this (@$data) {
@@ -52,16 +51,23 @@ sub country_code_types {
    return \@types;
 }
 
+#
 # Port numbers:
 # http://www.iana.org/protocols
 # http://www.iana.org/assignments/service-names-port-numbers/service-names-port-numbers.xhtml
-
+#
 sub update {
    my $self = shift;
+   my ($output) = @_;
+
+   $output ||= $self->output;
+   $self->brik_help_run_undef_arg('update', $output) or return;
+
+   my $datadir = $self->datadir;
 
    my $uri = 'http://www.iana.org/domains/root/db';
 
-   my $get = $self->get($uri) or return $self->log->error("update: get failed");
+   my $get = $self->get($uri) or return;
    my $html = $get->{content};
 
    # <tr class="iana-group-1 iana-type-2">
@@ -72,19 +78,14 @@ sub update {
    # </tr>
 
    my @cc = ();
-   while ($html =~ m{<tr class="iana-group-\d+\s+iana-type-\d+">(.*?)</tr>}gcs) {
+   while ($html =~ m{<span class="domain tld">(.*?)</tr>}gcs) {
       my $this = $1;
 
       $this =~ s/\n//g;
 
       $self->debug && $self->log->debug("update: this[$this]");
 
-      #my ($tld, $type, $country, $sponsor) = ($this =~ m{^.*?<a href.*?>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*>(.*?)</span>.*$});
-      my ($tld, $type, $country, $sponsor) = ($this =~ m{^.*?<a href.*?>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*<span.*?>(.*?)</span>.*$});
-
-      #print "tld[$tld]\n";
-      #print "type[$type]\n";
-      #print "sponsor[$sponsor]\n";
+      my ($tld, $type, $country, $sponsor) = ($this =~ m{^.*?<a href.*?>(.*?)<.*?<td>(.*?)<.*?<td>(.*?)<.*$});
 
       push @cc, {
          tld => $tld,
@@ -94,28 +95,13 @@ sub update {
       };
    }
 
-   return \@cc;
-}
-
-sub save {
-   my $self = shift;
-   my ($data, $output) = @_;
-
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('save'));
-   }
-
-   $output ||= $self->output;
-
-   my $datadir = $self->datadir;
-
-   my $file_csv = Metabrik::File::Csv->new_from_brik($self) or return;
-   $file_csv->overwrite(1);
-   $file_csv->encoding('utf8');
+   my $fc = Metabrik::File::Csv->new_from_brik_init($self) or return;
+   $fc->append(0);
+   $fc->overwrite(1);
+   $fc->encoding('utf8');
 
    my $output_file = $datadir.'/'.$output;
-   $file_csv->write($data, $output_file)
-      or return $self->log->error("save: write failed");
+   $fc->write(\@cc, $output_file) or return;
 
    return $output_file;
 }
@@ -125,16 +111,15 @@ sub load {
    my ($input) = @_;
 
    $input ||= $self->input;
-   if (! -f $input) {
-      return $self->log->error("load: file [$input] not found");
-   }
+   $self->brik_help_run_undef_arg('load', $input) or return;
+   $self->brik_help_run_file_not_found('load', $input) or return;
 
    my $datadir = $self->datadir;
 
-   my $file_csv = Metabrik::File::Csv->new_from_brik($self) or return;
-   $file_csv->first_line_is_header(1);
+   my $fc = Metabrik::File::Csv->new_from_brik_init($self) or return;
+   $fc->first_line_is_header(1);
 
-   my $csv = $file_csv->read($datadir.'/'.$input);
+   my $csv = $fc->read($datadir.'/'.$input) or return;
 
    return $csv;
 }
@@ -149,7 +134,7 @@ Metabrik::Lookup::Countrycode - lookup::countrycode Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
