@@ -1,5 +1,5 @@
 #
-# $Id: Threatlist.pm,v 550398ff8391 2015/11/18 06:15:52 gomor $
+# $Id: Threatlist.pm,v 6391b00ed43b 2016/01/26 20:00:14 gomor $
 #
 # lookup::threatlist Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 550398ff8391 $',
-      tags => [ qw(unstable lookup ipv4 ipv6 ip threat threatlist) ],
+      revision => '$Revision: 6391b00ed43b $',
+      tags => [ qw(unstable ipv4 ipv6 ip threat) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          datadir => [ qw(datadir) ],
       },
@@ -51,7 +53,6 @@ sub update {
       'abusech-spyeyetracker.txt.gz' => 'https://spyeyetracker.abuse.ch/blocklist.php?download=ipblocklist',
       'abusech-zeustracker-badips.txt.gz' => 'https://zeustracker.abuse.ch/blocklist.php?download=badips',
       'abusech-zeustracker.txt.gz' => 'https://zeustracker.abuse.ch/blocklist.php?download=ipblocklist',
-      'amazonaws-top-1m.csv.zip' => 'http://s3.amazonaws.com/alexa-static/top-1m.csv.zip',
       'iana-tlds-alpha-by-domain.txt' => 'http://data.iana.org/TLD/tlds-alpha-by-domain.txt',
       'publicsuffix-effective_tld_names.dat.gz' => 'https://publicsuffix.org/list/effective_tld_names.dat',
    );
@@ -87,30 +88,31 @@ sub update {
    my $fc = Metabrik::File::Compress->new_from_brik_init($self) or return;
    $fc->datadir($datadir);
 
+   my @updated = ();
    for my $f (keys %mirror) {
       my $files = $cw->mirror($mirror{$f}, $f) or next;
       for my $file (@$files) {
+         my $outfile = $file;
          if ($file =~ /\.gz$/) {
-            (my $outfile = $file) =~ s/\.gz$//;
-            $fc->uncompress($datadir.'/'.$file, $outfile);
+            ($outfile = $file) =~ s/\.gz$//;
+            $fc->uncompress($file, $outfile) or next;
          }
          elsif ($file =~ /\.zip$/) {
-            (my $outfile = $file) =~ s/\.zip$//;
-            $fc->uncompress($datadir.'/'.$file, $outfile);
+            ($outfile = $file) =~ s/\.zip$//;
+            $fc->uncompress($file, $outfile) or next;
          }
+         push @updated, $outfile;
       }
    }
 
-   return 1;
+   return \@updated;
 }
 
 sub from_ipv4 {
    my $self = shift;
    my ($ipv4) = @_;
 
-   if (! defined($ipv4)) {
-      return $self->log->error($self->brik_help_run('from_ipv4'));
-   }
+   $self->brik_help_run_undef_arg('from_ipv4', $ipv4) or return;
 
    my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
    if (! $na->is_ipv4($ipv4)) {
@@ -222,7 +224,7 @@ Metabrik::Lookup::Threatlist - lookup::threatlist Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
