@@ -1,5 +1,5 @@
 #
-# $Id: Address.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Address.pm,v 35a2fef2b5f8 2016/01/19 13:11:10 gomor $
 #
 # network::address Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: 35a2fef2b5f8 $',
       tags => [ qw(unstable netmask) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -122,10 +122,14 @@ sub range_to_cidr {
    $self->brik_help_run_undef_arg('range_to_cidr', $first) or return;
    $self->brik_help_run_undef_arg('range_to_cidr', $last) or return;
 
-   # IPv4 and IPv6 compliant
-   my @list = Net::CIDR::range2cidr("$first-$last");
+   if ($self->is_ip($first) && $self->is_ip($last)) {
+      # IPv4 and IPv6 compliant
+      my @list = Net::CIDR::range2cidr("$first-$last");
 
-   return \@list;
+      return \@list;
+   }
+
+   return $self->log->error("range_to_cidr: first [$first] or last [$last] not a valid IP address");
 }
 
 sub is_ip {
@@ -331,12 +335,12 @@ sub is_ipv4_subnet {
 
    my ($address, $cidr) = $subnet =~ m{^(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})/(\d+)$};
    if (! defined($address) || ! defined($cidr)) {
-      $self->log->verbose("is_ipv4_subnet: not a subnet [$subnet]");
+      $self->debug && $self->log->debug("is_ipv4_subnet: not a subnet [$subnet]");
       return 0;
    }
 
    if ($cidr < 0 || $cidr > 32) {
-      $self->log->verbose("is_ipv4_subnet: not a valid CIDR mask [$cidr]");
+      $self->debug && $self->log->debug("is_ipv4_subnet: not a valid CIDR mask [$cidr]");
       return 0;
    }
 
