@@ -1,5 +1,5 @@
 #
-# $Id: Arp.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Arp.pm,v 677135422623 2016/01/29 18:14:57 gomor $
 #
 # network::arp Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Network::Frame Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: 677135422623 $',
       tags => [ qw(unstable cache poison eui64 discover scan eui-64) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -106,7 +106,7 @@ sub half_poison {
 
    my $sc = Metabrik::Shell::Command->new_from_brik_init($self) or return;
    my $sp = Metabrik::System::Process->new_from_brik_init($self) or return;
-   my $pidfile = $sp->daemonize(sub { $sc->system($cmd) });
+   my $pidfile = $sp->start(sub { $sc->system($cmd) });
    $self->_pidfile($pidfile);
 
    $self->log->info("half_poison: daemonized to pidfile[$pidfile]");
@@ -132,7 +132,7 @@ sub full_poison {
 
    my $sc = Metabrik::Shell::Command->new_from_brik_init($self) or return;
    my $sp = Metabrik::System::Process->new_from_brik_init($self) or return;
-   my $pidfile = $sp->daemonize(sub { $sc->system($cmd) });
+   my $pidfile = $sp->start(sub { $sc->system($cmd) });
    $self->_pidfile($pidfile);
 
    $self->log->info("full_poison: daemonized to pidfile[$pidfile]");
