@@ -1,5 +1,5 @@
 #
-# $Id: Command.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Command.pm,v 00ead8d799a8 2016/02/14 14:23:21 gomor $
 #
 # shell::command Brik
 #
@@ -7,11 +7,13 @@ package Metabrik::Shell::Command;
 use strict;
 use warnings;
 
+our $VERSION = '1.20';
+
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
+      revision => '$Revision: 00ead8d799a8 $',
       tags => [ qw(exec execute) ],
       attributes => {
          as_array => [ qw(0|1) ],
@@ -21,6 +23,7 @@ sub brik_properties {
          ignore_error => [ qw(0|1) ],
          use_sudo => [ qw(0|1) ],
          use_pager => [ qw(0|1) ],
+         use_globbing => [ qw(0|1) ],
          sudo_args => [ qw(args) ],
       },
       attributes_default => {
@@ -31,12 +34,16 @@ sub brik_properties {
          ignore_error => 1,
          use_sudo => 0,
          use_pager => 0,
+         use_globbing => 1,
          sudo_args => '-E',  # Keep environment
       },
       commands => {
          system => [ qw(command) ],
+         sudo_system => [ qw(command) ],
          capture => [ qw(command) ],
+         sudo_capture => [ qw(command) ],
          execute => [ qw(command) ],
+         sudo_execute => [ qw(command) ],
       },
       require_modules => {
          'IPC::Run3' => [ ],
@@ -79,7 +86,8 @@ sub system {
 
    $command = join(' ', @toks);
 
-   if ($self->use_sudo) {
+   # Use sudo only when not root
+   if ($self->use_sudo && $< != 0) {
       my @sudo = ( "sudo" );
       if (! ref($self->sudo_args) && length($self->sudo_args)) {
          my @args = split(/\s+/, $self->sudo_args);
@@ -87,7 +95,7 @@ sub system {
       }
       $command = join(' ', @sudo)." $command";
       @toks = ( @sudo, @toks );
-      $self->log->verbose("system: using sudo: running [$command]");
+      $self->log->verbose("system: using sudo: cmd[$command]");
    }
 
    if ($self->use_pager) {
@@ -97,21 +105,34 @@ sub system {
 
    my $r = CORE::system($command);
 
-   $self->debug && $self->log->debug("system: return code [$r] with status [$?]");
+   $self->debug && $self->log->debug("system: command returned code [$r] with status [$?]");
 
    if (! $self->ignore_error && $? != 0) {
+      $self->log->verbose("system: exit code[$?]");
       # Failure, we return the program exit code
-      return $? >> 8;
+      $self->debug && $self->log->debug("system: program exit code [$?]");
+      return $?;
    }
 
-   # Success
-   if ($r == 0) {
-      return 1;
-   }
+   $self->debug && $self->log->debug("system: program exit with success");
 
    return 1;
 }
 
+sub sudo_system {
+   my $self = shift;
+   my ($cmd, @args) = @_;
+
+   $self->brik_help_run_undef_arg('sudo_system', $cmd) or return;
+
+   my $prev = $self->use_sudo;
+   $self->use_sudo(1);
+   my $r = $self->system($cmd, @args);
+   $self->use_sudo($prev);
+
+   return $r;
+}
+
 sub capture {
    my $self = shift;
    my ($cmd, @args) = @_;
@@ -146,15 +167,18 @@ sub capture {
    }
 
    # Perform file globbing, if any
-   my @globbed = ();
-   for (@toks) {
-      push @globbed, glob($_);
+   if ($self->use_globbing) {
+      my @globbed = ();
+      for (@toks) {
+         push @globbed, glob($_);
+      }
+      @toks = @globbed;
    }
-   @toks = @globbed;
 
    $command = join(' ', @toks);
 
-   if ($self->use_sudo) {
+   # Use sudo only when not root
+   if ($self->use_sudo && $< != 0) {
       my @sudo = ( "sudo" );
       if (! ref($self->sudo_args) && length($self->sudo_args)) {
          my @args = split(/\s+/, $self->sudo_args);
@@ -162,13 +186,14 @@ sub capture {
       }
       $command = join(' ', @sudo)." $command";
       @toks = ( @sudo, @toks );
-      $self->log->verbose("capture: using sudo: running [$command]");
+      $self->log->verbose("capture: using sudo: cmd[$command]");
    }
 
    my $out;
    my $err;
    eval {
-      IPC::Run3::run3(\@toks, undef, \$out, \$err);
+      my $cmd = join(' ', @toks);
+      IPC::Run3::run3($cmd, undef, \$out, \$err);
    };
    # Error in executing run3()
    if ($@) {
@@ -213,6 +238,20 @@ sub capture {
    return $out;
 }
 
+sub sudo_capture {
+   my $self = shift;
+   my ($cmd, @args) = @_;
+
+   $self->brik_help_run_undef_arg('sudo_capture', $cmd) or return;
+
+   my $prev = $self->use_sudo;
+   $self->use_sudo(1);
+   my $r = $self->capture($cmd, @args);
+   $self->use_sudo($prev);
+
+   return $r;
+}
+
 sub execute {
    my $self = shift;
    my ($cmd, @args) = @_;
@@ -230,6 +269,23 @@ sub execute {
    return;
 }
 
+sub sudo_execute {
+   my $self = shift;
+   my ($cmd, @args) = @_;
+
+   $self->brik_help_run_undef_arg('sudo_execute', $cmd) or return;
+
+   if ($self->capture_mode) {
+      return $self->sudo_capture($cmd, @args);
+   }
+   else {  # non-capture mode
+      return $self->sudo_system($cmd, @args);
+   }
+
+   # Unknown error
+   return;
+}
+
 1;
 
 __END__
