@@ -1,5 +1,5 @@
 #
-# $Id: Ini.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Ini.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
 #
 # string::ini Brik
 #
@@ -11,8 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
-      tags => [ qw(unstable encode decode ini) ],
+      revision => '$Revision: 1cdea52670de $',
+      tags => [ qw(unstable encode decode) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
          encode => [ qw($data_hash) ],
          decode => [ qw($data) ],
@@ -28,13 +30,8 @@ sub encode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('encode'));
-   }
-
-   if (ref($data) ne 'HASH') {
-      return $self->log->error("encode: you need to give data as HASHREF");
-   }
+   $self->brik_help_run_undef_arg('encode', $data) or return;
+   $self->brik_help_run_invalid_arg('encode', $data, 'HASH') or return;
 
    my $copy = Storable::dclone($data);
    bless($copy, 'Config::Tiny');
@@ -53,9 +50,7 @@ sub decode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('decode'));
-   }
+   $self->brik_help_run_undef_arg('decode', $data) or return;
 
    my ($config) = Config::Tiny->read_string($data);
 
@@ -72,7 +67,7 @@ Metabrik::String::Ini - string::ini Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
