@@ -1,5 +1,5 @@
 #
-# $Id: Xml.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Xml.pm,v 00ead8d799a8 2016/02/14 14:23:21 gomor $
 #
 # string::xml Brik
 #
@@ -7,19 +7,26 @@ package Metabrik::String::Xml;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
-      tags => [ qw(unstable encode decode xml) ],
+      revision => '$Revision: 00ead8d799a8 $',
+      tags => [ qw(unstable encode decode) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       commands => {
+         install => [ ], # Inherited
          encode => [ qw($data_hash) ],
          decode => [ qw($data) ],
       },
       require_modules => {
          'XML::Simple' => [ ],
       },
+      need_packages => {
+         ubuntu => [ qw(libexpat1-dev libxml2-dev) ],
+         freebsd => [ qw(libxml2) ],
+      },
    };
 }
 
@@ -27,13 +34,8 @@ sub encode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('encode'));
-   }
-
-   if (ref($data) ne 'HASH') {
-      return $self->log->error("encode: you need to give data as HASHREF");
-   }
+   $self->brik_help_run_undef_arg('encode', $data) or return;
+   $self->brik_help_run_invalid_arg('encode', $data, 'HASH') or return;
 
    my $xs = XML::Simple->new;
 
@@ -44,9 +46,7 @@ sub decode {
    my $self = shift;
    my ($data) = @_;
 
-   if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('decode'));
-   }
+   $self->brik_help_run_undef_arg('decode', $data) or return;
 
    my $xs = XML::Simple->new;
 
@@ -63,7 +63,7 @@ Metabrik::String::Xml - string::xml Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
