@@ -1,5 +1,5 @@
 #
-# $Id: Universal.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Universal.pm,v 811ac7ccde81 2016/02/22 18:15:08 gomor $
 #
 # time::universal Brik
 #
@@ -11,18 +11,24 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
-      tags => [ qw(time timezone) ],
+      revision => '$Revision: 811ac7ccde81 $',
+      tags => [ qw(unstable timezone) ],
+      author => 'GomoR <GomoR[at]metabrik.org>',
+      license => 'http://opensource.org/licenses/BSD-3-Clause',
       attributes => {
          timezone => [ qw(string) ],
+         separator => [ qw(character) ],
       },
       attributes_default => {
          timezone => [ 'Europe/Paris' ],
+         separator => '-',
       },
       commands => {
          list_timezones => [ ],
          search_timezone => [ qw(string) ],
          localtime => [ qw(timezone|OPTIONAL) ],
+         today => [ qw(separator|OPTIONAL) ],
+         date => [ ],
       },
       require_modules => {
          'DateTime' => [ ],
@@ -32,6 +38,8 @@ sub brik_properties {
 }
 
 sub list_timezones {
+   my $self = shift;
+
    return DateTime::TimeZone->all_names;
 }
 
@@ -39,9 +47,7 @@ sub search_timezone {
    my $self = shift;
    my ($pattern) = @_;
 
-   if (! defined($pattern)) {
-      return $self->log->error($self->brik_help_run('search_timezone'));
-   }
+   $self->brik_help_run_undef_arg('search_timezone', $pattern) or return;
 
    my $list = $self->list_timezones;
 
@@ -60,9 +66,7 @@ sub localtime {
    my ($timezone) = @_;
 
    $timezone ||= $self->timezone;
-   if (! defined($timezone)) {
-      return $self->log->error($self->brik_help_set('timezone'));
-   }
+   $self->brik_help_run_undef_arg('localtime', $timezone) or return;
 
    my $time = {};
    if (ref($timezone) eq 'ARRAY') {
@@ -83,6 +87,26 @@ sub localtime {
    return $time;
 }
 
+sub today {
+   my $self = shift;
+   my ($sep) = @_;
+
+   $sep ||= $self->separator;
+
+   my @a = CORE::localtime();
+   my $y = $a[5] + 1900;
+   my $m = $a[4] + 1;
+   my $d = $a[3];
+
+   return sprintf("%04d$sep%02d$sep%02d", $y, $m, $d);
+}
+
+sub date {
+   my $self = shift;
+
+   return CORE::localtime()."";
+}
+
 1;
 
 __END__
@@ -93,7 +117,7 @@ Metabrik::Time::Universal - time::universal Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
